==> kara-uc-1.1.16.tgz: package/src/kara-uc/util/dateTime.js <==

class DateUtil extends Date {
  static timeago(dateTimeStamp) {  //dateTimeStamp是一个时间毫秒，注意时间戳是秒的形式，在这个毫秒的基础上除以1000，就是十位数的时间戳。13位数的都是时间毫秒。
    var minute = 1000 * 60;      //把分，时，天，周，半个月，一个月用毫秒表示
    var hour = minute * 60;
    var day = hour * 24;
    var week = day * 7;
    var halfamonth = day * 15;
    var month = day * 30;
    var now = new Date().getTime();   //获取当前时间毫秒
    var result = ''
    var diffValue = now - dateTimeStamp;//时间差

    if(diffValue < 0){
        return;
    }
    var minC = diffValue/minute;  //计算时间差的分，时，天，周，月
    var hourC = diffValue/hour;
    var dayC = diffValue/day;
    var weekC = diffValue/week;
    var monthC = diffValue/month;
    if(monthC >= 1 && monthC <= 3){
        result = " " + parseInt(monthC) + " 个月前"
    }else if(weekC >= 1 && weekC <= 3){
        result = " " + parseInt(weekC) + " 周前"
    }else if(dayC >= 1 && dayC <= 6){
        result = " " + parseInt(dayC) + " 天前"
    }else if(hourC >= 1 && hourC <= 23){
        result = " " + parseInt(hourC) + " 小时前"
    }else if(minC >= 1 && minC <= 59){
        result =" " + parseInt(minC) + " 分钟前"
    }else if(diffValue >= 0 && diffValue <= minute){
        result = "刚刚"
    }else {
        var datetime = new Date();
        datetime.setTime(dateTimeStamp);
        var Nyear = datetime.getFullYear();
        var Nmonth = datetime.getMonth() + 1 < 10 ? "0" + (datetime.getMonth() + 1) : datetime.getMonth() + 1;
        var Ndate = datetime.getDate() < 10 ? "0" + datetime.getDate() : datetime.getDate();
        var Nhour = datetime.getHours() < 10 ? "0" + datetime.getHours() : datetime.getHours();
        var Nminute = datetime.getMinutes() < 10 ? "0" + datetime.getMinutes() : datetime.getMinutes();
        var Nsecond = datetime.getSeconds() < 10 ? "0" + datetime.getSeconds() : datetime.getSeconds();
        result = Nyear + "-" + Nmonth + "-" + Ndate
    }
    return result;
  }
  static format(date, fmt) {
    const o = {
      'M+': date.getMonth() + 1, // 月份
      'd+': date.getDate(), // 日
      'h+': date.getHours(), // 小时
      'm+': date.getMinutes(), // 分
      's+': date.getSeconds(), // 秒
      'q+': Math.floor((date.getMonth() + 3) / 3), // 季度
      S: date.getMilliseconds(), // 毫秒
    };
    const week = {
      "0" : "日",
      "1" : "一",
      "2" : "二",
      "3" : "三",
      "4" : "四",
      "5" : "五",
      "6" : "六"
    };
    let replaceFmt = (fmt && fmt !== '') ? fmt : ''; // 2017.2.10更新，设置默认值，保证replace时不会因为没有赋值而报错
    if (/(y+)/.test(fmt)) {
      replaceFmt = fmt.replace(RegExp.$1, (`${date.getFullYear()}`).substr(4 - RegExp.$1.length));
    }
    if(/(E+)/.test(fmt)){
      replaceFmt = replaceFmt.replace(RegExp.$1, (`${((RegExp.$1.length>1) ?  "星期" : "周")}${week[date.getDay()]}`));
    }
    Object.keys(o).forEach((k) => {
      if (new RegExp(`(${k})`).test(fmt)) {
        replaceFmt = replaceFmt.replace(RegExp.$1, (RegExp.$1.length === 1) ?
            (o[k]) :
            ((`00${o[k]}`).substr((`${o[k]}`).length)));
      }
    });
    return replaceFmt;
  }
  static DateShow(dateTimeStamp) {
      if(this.format(new Date(),'yyyy-MM-dd') === this.format(new Date(dateTimeStamp),'yyyy-MM-dd')){
          return new Date(dateTimeStamp).getHours() + ':' + new Date(dateTimeStamp).getMinutes()
      }
      else {
          return this.format(new Date(dateTimeStamp),'yyyy-MM-dd')
      }
  }
}


export default DateUtil;

==> kara-uc-1.1.29.tgz: package/src/kara-uc/util/dateTime.js <==

class DateUtil extends Date {
  static timeago(dateTimeStamp) {  //dateTimeStamp是一个时间毫秒，注意时间戳是秒的形式，在这个毫秒的基础上除以1000，就是十位数的时间戳。13位数的都是时间毫秒。
    var minute = 1000 * 60;      //把分，时，天，周，半个月，一个月用毫秒表示
    var hour = minute * 60;
    var day = hour * 24;
    var week = day * 7;
    var halfamonth = day * 15;
    var month = day * 30;
    var now = new Date().getTime();   //获取当前时间毫秒
    var result = ''
    var diffValue = now - dateTimeStamp;//时间差

    if(diffValue < 0){
        return;
    }
    var minC = diffValue/minute;  //计算时间差的分，时，天，周，月
    var hourC = diffValue/hour;
    var dayC = diffValue/day;
    var weekC = diffValue/week;
    var monthC = diffValue/month;
    if(monthC >= 1 && monthC <= 3){
        result = " " + parseInt(monthC) + " 个月前"
    }else if(weekC >= 1 && weekC <= 3){
        result = " " + parseInt(weekC) + " 周前"
    }else if(dayC >= 1 && dayC <= 6){
        result = " " + parseInt(dayC) + " 天前"
    }else if(hourC >= 1 && hourC <= 23){
        result = " " + parseInt(hourC) + " 小时前"
    }else if(minC >= 1 && minC <= 59){
        result =" " + parseInt(minC) + " 分钟前"
    }else if(diffValue >= 0 && diffValue <= minute){
        result = "刚刚"
    }else {
        var datetime = new Date();
        datetime.setTime(dateTimeStamp);
        var Nyear = datetime.getFullYear();
        var Nmonth = datetime.getMonth() + 1 < 10 ? "0" + (datetime.getMonth() + 1) : datetime.getMonth() + 1;
        var Ndate = datetime.getDate() < 10 ? "0" + datetime.getDate() : datetime.getDate();
        var Nhour = datetime.getHours() < 10 ? "0" + datetime.getHours() : datetime.getHours();
        var Nminute = datetime.getMinutes() < 10 ? "0" + datetime.getMinutes() : datetime.getMinutes();
        var Nsecond = datetime.getSeconds() < 10 ? "0" + datetime.getSeconds() : datetime.getSeconds();
        result = Nyear + "-" + Nmonth + "-" + Ndate
    }
    return result;
  }
  static format(date, fmt) {
    const o = {
      'M+': date.getMonth() + 1, // 月份
      'd+': date.getDate(), // 日
      'h+': date.getHours(), // 小时
      'm+': date.getMinutes(), // 分
      's+': date.getSeconds(), // 秒
      'q+': Math.floor((date.getMonth() + 3) / 3), // 季度
      S: date.getMilliseconds(), // 毫秒
    };
    const week = {
      "0" : "日",
      "1" : "一",
      "2" : "二",
      "3" : "三",
      "4" : "四",
      "5" : "五",
      "6" : "六"
    };
    let replaceFmt = (fmt && fmt !== '') ? fmt : ''; // 2017.2.10更新，设置默认值，保证replace时不会因为没有赋值而报错
    if (/(y+)/.test(fmt)) {
      replaceFmt = fmt.replace(RegExp.$1, (`${date.getFullYear()}`).substr(4 - RegExp.$1.length));
    }
    if(/(E+)/.test(fmt)){
      replaceFmt = replaceFmt.replace(RegExp.$1, (`${((RegExp.$1.length>1) ?  "星期" : "周")}${week[date.getDay()]}`));
    }
    Object.keys(o).forEach((k) => {
      if (new RegExp(`(${k})`).test(fmt)) {
        replaceFmt = replaceFmt.replace(RegExp.$1, (RegExp.$1.length === 1) ?
            (o[k]) :
            ((`00${o[k]}`).substr((`${o[k]}`).length)));
      }
    });
    return replaceFmt;
  }
  static DateShow(dateTimeStamp) {
      if(this.format(new Date(),'yyyy-MM-dd') === this.format(new Date(dateTimeStamp),'yyyy-MM-dd')){new Date(dateTimeStamp).getMinutes()
          const minutes = new Date(dateTimeStamp).getMinutes();
          return new Date(dateTimeStamp).getHours() + ':' + (minutes < 10 ? `0${minutes}` : minutes)
      }
      else {
          return this.format(new Date(dateTimeStamp),'yyyy-MM-dd')
      }
  }
}


export default DateUtil;
